@@ -1,12 +1,12 @@
 ( cd opt/kde/lib ; rm -rf libamaroklib.so.1 )
 ( cd opt/kde/lib ; ln -sf libamaroklib.so.1.0.0 libamaroklib.so.1 )
-( cd opt/kde/lib ; rm -rf libmediadevicelib.so )
-( cd opt/kde/lib ; ln -sf libmediadevicelib.so.1 libmediadevicelib.so )
-( cd opt/kde/lib ; rm -rf libamarokpud.so.1 )
-( cd opt/kde/lib ; ln -sf libamarokpud.so.1.0.0 libamarokpud.so.1 )
 ( cd opt/kde/lib ; rm -rf libamaroklib.so )
 ( cd opt/kde/lib ; ln -sf libamaroklib.so.1 libamaroklib.so )
-( cd opt/kde/lib ; rm -rf libmediadevicelib.so.1 )
-( cd opt/kde/lib ; ln -sf libmediadevicelib.so.1.0.0 libmediadevicelib.so.1 )
+( cd opt/kde/lib ; rm -rf libamarokpud.so.1 )
+( cd opt/kde/lib ; ln -sf libamarokpud.so.1.0.0 libamarokpud.so.1 )
 ( cd opt/kde/lib ; rm -rf libamarokpud.so )
 ( cd opt/kde/lib ; ln -sf libamarokpud.so.1 libamarokpud.so )
+( cd opt/kde/lib ; rm -rf libamarokocsclient.so.4 )
+( cd opt/kde/lib ; ln -sf libamarokocsclient.so.4.3.0 libamarokocsclient.so.4 )
+( cd opt/kde/lib ; rm -rf libamarokocsclient.so )
+( cd opt/kde/lib ; ln -sf libamarokocsclient.so.4 libamarokocsclient.so )
